/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */
package de.bsvrz.vew.bmvew.bmvew.meldung;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.TextValue;
import de.bsvrz.dav.daf.main.Data.TimeValue;

/**
 *  Die Klasse kapselt die Daten des Benutzeranteils einer Betriebsmeldung
 *
 * @version $Revision: 1.1 $ / $Date: 2009/09/24 12:50:45 $ / ($Author: Pittner $)
 *
 * @author Dambach-Werke GmbH
 * @author Timo Pittner
 *
 */
public class BenutzerAnteil
{
  /**
   * Der Zeitstempel
   */
  private Long _zeit;

  /**
   * Der Benutzertext
   */
  private TextValue _text;
  
  /**
   * Der Urlasser
   */
  private Data _urlasser;

  /**
   * Konstruktor
   * 
   * @param zeit
   * @param text
   * @param urlasser
   */
  public BenutzerAnteil(Long zeit, TextValue text, Data urlasser)
  {
    if (zeit == null || text == null || urlasser == null)
      throw new IllegalArgumentException();

    _zeit = zeit;
    _text = text;
    _urlasser = urlasser; 
    

  }

  /**
   * Konstruktor
   * 
   * @param zeit
   * @param text
   * @param urlasser
   */
  public BenutzerAnteil(TimeValue zeit, TextValue text, Data urlasser)
  {
    if (zeit == null || text == null || urlasser == null)
      throw new IllegalArgumentException();

    _zeit = zeit.getMillis();
    _text = text;
    _urlasser = urlasser; 

  }

  /**
   * Konstruktor
   * 
   * @param benutzAnteil
   */
  public BenutzerAnteil(Data benutzAnteil)
  {
    if (benutzAnteil == null)
      throw new IllegalArgumentException();

    _zeit = benutzAnteil.getItem("Zeitstempel").asTimeValue().getMillis();
    _text = benutzAnteil.getItem("MeldungsText").asTextValue();
    _urlasser  = benutzAnteil.getItem("Urlasser");

    if (_zeit == null || _text == null || _urlasser == null)
      throw new IllegalArgumentException();

  }

  /* (non-Javadoc)
   * @see java.lang.Object#equals(java.lang.Object)
   */
  @Override
  public boolean equals(Object obj)
  {
    // TODO Auto-generated method stub
    InformationsAnteil vergleich = (InformationsAnteil)obj;

    if (_zeit.equals(vergleich.getZeit()) && _text.equals(vergleich.getText()))
    {

      return true;
    }

    return false;

  }

  public Long getZeit()
  {
    return _zeit;
  }

  public void setZeit(Long zeit)
  {
    _zeit = zeit;
  }

  public TextValue getText()
  {
    return _text;
  }

  public void setText(TextValue text)
  {
    _text = text;
  }

  public Data getUrlasser()
  {
    return _urlasser;
  }

  public void setUrlasser(Data urlasser)
  {
    _urlasser = urlasser;
  }

}
